summaryrefslogtreecommitdiff
path: root/src/html/html_tablecell_element.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/html/html_tablecell_element.c')
-rw-r--r--src/html/html_tablecell_element.c23
1 files changed, 10 insertions, 13 deletions
diff --git a/src/html/html_tablecell_element.c b/src/html/html_tablecell_element.c
index c881440..c106b4f 100644
--- a/src/html/html_tablecell_element.c
+++ b/src/html/html_tablecell_element.c
@@ -28,12 +28,12 @@ static struct dom_element_protected_vtable _protect_vtable = {
/**
* Create a dom_html_table_cell_element table_cell
*
* \param doc The document table_cell
* \param ele The returned element table_cell
* \return DOM_NO_ERR on success, appropriate dom_exception on failure.
*/
-dom_exception _dom_html_table_cell_element_create(struct dom_html_document *doc,
- dom_string *tag_name, dom_string *namespace, dom_string *prefix,
+dom_exception _dom_html_table_cell_element_create(
+ struct dom_html_element_create_params *params,
struct dom_html_table_cell_element **ele)
{
struct dom_node_internal *node;
@@ -47,24 +47,21 @@ dom_exception _dom_html_table_cell_element_create(struct dom_html_document *doc,
node->base.vtable = &_dom_html_element_vtable;
node->vtable = &_protect_vtable;
- return _dom_html_table_cell_element_initialise(doc, tag_name,
- namespace, prefix, *ele);
+ return _dom_html_table_cell_element_initialise(params, *ele);
}
/**
* Initialise a dom_html_table_cell_element table_cell
*
* \param doc The document table_cell
* \param ele The dom_html_table_cell_element table_cell
* \return DOM_NO_ERR on success, appropriate dom_exception on failure.
*/
-dom_exception _dom_html_table_cell_element_initialise(struct dom_html_document *doc,
- dom_string *tag_name, dom_string *namespace, dom_string *prefix,
+dom_exception _dom_html_table_cell_element_initialise(
+ struct dom_html_element_create_params *params,
struct dom_html_table_cell_element *ele)
{
- return _dom_html_element_initialise(doc, &ele->base,
- tag_name,
- namespace, prefix);
+ return _dom_html_element_initialise(params, &ele->base);
}
/**
@@ -28,12 +28,12 @@ static struct dom_element_protected_vtable _protect_vtable = {
* Create a dom_html_table_cell_element table_cell
*
- * \param doc The document table_cell
- * \param ele The returned element table_cell
+ * \param params The html element creation parameters
+ * \param ele The returned element table_cell
* \return DOM_NO_ERR on success, appropriate dom_exception on failure.
*/
@@ -47,24 +47,21 @@ dom_exception _dom_html_table_cell_element_create(struct dom_html_document *doc,
* Initialise a dom_html_table_cell_element table_cell
*
- * \param doc The document table_cell
- * \param ele The dom_html_table_cell_element table_cell
+ * \param params The html element creation parameters
+ * \param ele The dom_html_table_cell_element table_cell
* \return DOM_NO_ERR on success, appropriate dom_exception on failure.
*/